/*
 *	var.h
 *
 *	external variable declarations
 */

extern char *myname;
extern char *mydomain;
CONST extern char nullstr[];
CONST extern char curstr[];
CONST extern char draftstr[];
CONST extern char curfolderstr[];
CONST extern char pathsocket[];
CONST extern char pathpty[];
CONST extern char pathstdin[];
CONST extern char pathstdout[];
CONST extern char pathstderr[];
extern char *origtty;
extern char *origws;
extern char **pwd_envp;
extern int sig_ignore;
extern char log_buf[MAXLINEBUF + 1];
extern char *auth_passwd;
extern int mh_protocol;
extern int isinetd;
extern int ischild;
extern int isdaemon;
#define	nullline		((char *)nullstr)

extern char *spooldir;
extern char *inboxdir;
extern char *draftdir;
extern char *mhbindir;
extern char *incproc;
extern char *rmmproc;
extern char *sendproc;
extern char *context;
extern int msgprotect;
extern int folderprotect;
extern char *sequence;
extern char *passwdfile;
extern char *incprompt;
extern char *pickfile;
extern char *envpath;
extern int inctimeout;
extern int rmmtimeout;
extern int sendtimeout;
extern int picktimeout;
extern int daemonize;
extern int interactive;
extern char *serverrc;
extern int portno;
extern char *piddir;
extern char *homepiddir;
extern char *logdir;
extern int maxlogsize;
extern int nosyslog;
extern char *allowfile;
extern char *denyfile;
extern char *hostname;
extern char *mhprofile;
extern char *mhpopdrc;
extern int sockettimeout;
extern char *mypasswd;
extern char *folders;
extern int debuglevel;
